import * as React from 'react';
export declare enum NotieLevel {
    INFO = "INFO",
    ERROR = "ERROR",
    SUCCESS = "SUCCESS",
    WARN = "WARN",
    FORCE = "FORCE",
    CONFIRM = "CONFIRM"
}
export declare const notieContainer: string;
export declare const notieMessage: string;
export declare const notieChoices: string;
export declare const notieButton: string;
/**
 * Settings for Notie
 */
export interface NotieSettings {
    /**
     * The message to be shown
     */
    message: string;
    /**
     * The type of alert-box to shown
     */
    level: NotieLevel;
    /**
     * Text to be shown for 'OK' button
     *
     * @default 'OK'
     */
    okBtnText?: string;
    /**
     * Text to be shown for 'Cancel' button
     *
     * @default 'Cancel'
     */
    cancelBtnText?: string;
    /**
     * The time (in ms) after which the alert-box disappears
     * @default 5000
     */
    ttl?: number;
}
export declare type NotieCallback = (...args: any[]) => void;
export declare const DEFAULT_TIMEOUT = 5000;
export declare class Notie extends React.Component<any, NotieSettings> {
    private dialog;
    private timeout;
    private confirmResolve;
    private confirmReject;
    static __singletonRef: Notie;
    static success(message: string, ttl?: number): void;
    static error(message: string, ttl?: number): void;
    static warn(message: string, ttl?: number): void;
    static info(message: string, ttl?: number): void;
    static confirm(message: string, props?: Pick<NotieSettings, 'okBtnText' | 'cancelBtnText'>): Promise<unknown>;
    static force(message: string, props?: Pick<NotieSettings, 'okBtnText' | 'cancelBtnText'>): Promise<unknown>;
    constructor(props: any);
    componentWillUnmount(): void;
    showNotie: (settings: NotieSettings) => void;
    hideNotie: (callback?: NotieCallback | undefined) => void;
    handleYes: () => void;
    handleNo: () => void;
    handleDismiss: () => void;
    rootRef: (c: HTMLDialogElement) => void;
    readonly forced: boolean;
    showSuccess: (message: string, ttl?: number | undefined) => void;
    showError: (message: string, ttl?: number | undefined) => void;
    showWarn: (message: string, ttl?: number | undefined) => void;
    showInfo: (message: string, ttl?: number | undefined) => void;
    showConfirm: (message: string, props?: Pick<NotieSettings, "okBtnText" | "cancelBtnText"> | undefined) => Promise<unknown>;
    showForce: (message: string, props?: Pick<NotieSettings, "okBtnText" | "cancelBtnText"> | undefined) => Promise<unknown>;
    render(): JSX.Element;
}
